"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Link = void 0;
const vue_1 = require("vue");
exports.Link = (0, vue_1.defineComponent)({
    props: {
        /** The link field data. */
        field: {
            type: Object,
            default() {
                return {};
            },
            required: true,
        },
        /**
         * Can be used to explicitly disable inline editing.
         * If true and `field.editable` has a value,
         * then `field.editable` will be processed and rendered as
         * component output. If false, `field.editable` value will be ignored and not rendered.
         */
        editable: {
            type: Boolean,
            default: true,
        },
        /**
         * Displays a link text ('description' in Sitecore) even when children exist
         * NOTE: when in Sitecore Experience Editor, this setting is ignored due to technical limitations, and the description is always rendered.
         */
        showLinkTextWithChildrenPresent: {
            type: Boolean,
            default: false,
        },
    },
    render() {
        const { field, editable, showLinkTextWithChildrenPresent } = this.$props;
        const children = this.$slots.default;
        const dynamicField = field;
        if (!field || (!dynamicField.editableFirstPart && !dynamicField.value && !dynamicField.href)) {
            return null;
        }
        // EXPERIENCE EDITOR RENDERING
        if (editable && dynamicField.editableFirstPart) {
            let markup = dynamicField.editableFirstPart;
            // in an ideal world, we'd pre-render Vue children here and inject them between editableFirstPart and editableLastPart.
            // However, we cannot combine arbitrary unparsed HTML (innerHTML) based components with actual vDOM components (the children)
            // because the innerHTML is not parsed - it'd make a discontinuous vDOM.
            // So, we'll go for the next best compromise of rendering the link field and children separately
            // under a wrapping div. Should be "good enough" for most cases - and write your own helper if it isn't. Or bring xEditor out of 2006.
            markup += dynamicField.editableLastPart;
            // this.$data should be passed along to the
            // `createElement` function in order to retain attributes and events
            // https://v3.vuejs.org/guide/render-function.html#render-functions
            const elementData = Object.assign(Object.assign({}, this.$data), { class: 'sc-link-wrapper', innerHTML: markup });
            const xEditorElement = (0, vue_1.h)('span', elementData);
            if (children) {
                const childElements = (0, vue_1.h)('span', { class: 'sc-link-editable-children-wrapper' }, children());
                return (0, vue_1.h)('span', { class: 'sc-link-editable-wrapper' }, [xEditorElement, childElements]);
            }
            return xEditorElement;
        }
        // handle link directly on field for forgetful devs
        const link = dynamicField.href ? field : dynamicField.value;
        if (!link) {
            return null;
        }
        const linkText = showLinkTextWithChildrenPresent || !children || children().length === 0
            ? link.text || link.href
            : null;
        const finalChildren = children ? [linkText, ...children()] : linkText;
        const qs = link.querystring ? `?${link.querystring}` : '';
        const anchor = link.anchor ? `#${link.anchor}` : '';
        // this.$data should be passed along to the
        // `createElement` function in order to retain attributes and events
        // https://v3.vuejs.org/guide/render-function.html#render-functions
        const data = Object.assign(Object.assign(Object.assign(Object.assign({}, this.$data), { class: link.class }), this.$attrs), { href: `${link.href}${qs}${anchor}`, title: link.title, target: link.target });
        return (0, vue_1.h)('a', data, finalChildren);
    },
});
